@@ -1,7 +1,6 @@
-#!/usr/bin/env python3
-
 import sys
 import os
+from datetime import date
 
 sys.path.append(os.path.join(os.path.abspath(os.pardir)))
 autodoc_mock_imports = ["_tkinter"]
@@ -11,8 +10,6 @@ project_root = os.path.dirname(cwd)
 sys.path.insert(0, os.path.abspath('source'))
 sys.path.insert(0, project_root)
 
-import pybliometrics
-
 # General configuration
 extensions = [
     'sphinx.ext.autodoc',
@@ -29,12 +26,14 @@ source_suffix = '.rst'
 master_doc = 'index'
 project = 'pybliometrics'
 author = 'Michael E. Rose and John Kitchin'
-copyright = '2017-2021 ' + author
+copyright = f"2017-{date.today().year} {author}"
 
-version = pybliometrics.__version__
-release = pybliometrics.__version__
+from pbr.version import VersionInfo
 
-language = None
+_v = VersionInfo('pybliometrics').semantic_version()
+version = _v.release_string()
+
+language = 'en'
 
 exclude_patterns = ['_build', 'Thumbs.db', '.DS_Store']
 
