@@ -1,8 +1,11 @@
-from pbr.version import VersionInfo
+import sys
 
-_v = VersionInfo('pybliometrics').semantic_version()
-__version__ = _v.release_string()
-version_info = _v.version_tuple()
+if sys.version_info >= (3, 8):
+    from importlib.metadata import version
+else:
+    from importlib_metadata import version
+
+__version__ = version("pybliometrics")
 
 __citation__ = 'Rose, Michael E. and John R. Kitchin: "pybliometrics: '\
     'Scriptable bibliometrics using a Python interface to Scopus", SoftwareX '\
