@@ -9,7 +9,7 @@ from nose.tools import assert_equal, assert_true
 from pybliometrics.scopus import AffiliationSearch
 
 s1 = AffiliationSearch('AF-ID(60021784)', refresh=30)
-s2 = AffiliationSearch('AFFIL(Max Planck Munich)', download=False)
+s2 = AffiliationSearch('AFFIL(Max Planck Munich)', download=False, refresh=True)
 
 
 def test_affiliations():
@@ -18,10 +18,10 @@ def test_affiliations():
     order = 'eid name variant documents city country parent'
     Affiliation = namedtuple('Affiliation', order)
     expected = Affiliation(eid='10-s2.0-60021784', name='New York University',
-        variant='', documents='0', city='New York', country='United States',
+        variant='', documents=0, city='New York', country='United States',
         parent='0')
-    assert_true(int(received1[0].documents) >= 90_000)
-    assert_equal(received1[0]._replace(documents="0"), expected)
+    assert_true(received1[0].documents >= 90_000)
+    assert_equal(received1[0]._replace(documents=0), expected)
 
 
 def test_affiliations_nodownload():
