@@ -2,10 +2,12 @@ from collections import namedtuple
 from functools import reduce
 from warnings import warn
 
+
 def filter_digits(s):
     """Helper function to remove non-digits characters from a string."""
     return "".join(filter(str.isdigit, s))
 
+
 def chained_get(container, path, default=None):
     """Helper function to perform a series of .get() methods on a dictionary
     or return the `default`.
@@ -90,6 +92,11 @@ def get_link(dct, idx, path=['coredata', 'link']):
         return None
 
 
+def html_unescape(s:str): 
+        from html import unescape
+        return unescape(s) if s else None
+
+
 def listify(element):
     """Helper function to turn an element into a list if it isn't a list yet.
     """
@@ -99,6 +106,14 @@ def listify(element):
         return [element]
 
 
+def make_float_if_possible(val):
+    """Attempt a conversion to float type."""
+    try:
+        return float(val)
+    except TypeError:
+        return val
+
+
 def make_int_if_possible(val):
     """Attempt a conversion to int type."""
     try:
